const webpack = require('webpack');
const ProgressBarPlugin = require('progress-bar-webpack-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

module.exports = {
    plugins: [
        new webpack.DefinePlugin({
            'process.env': {
                'NODE_ENV': JSON.stringify((process.env.NODE_ENV || 'development')),
            },
        }),
        new ProgressBarPlugin(),
        new ExtractTextPlugin('app.css'),
        new webpack.optimize.CommonsChunkPlugin({ name: 'vendors', filename: 'vendor.js' }),
    ],
    module: {
        rules: [{
            test: /\.less$/,
            use: ExtractTextPlugin.extract({
                fallback: 'style-loader',
                use: [
                    {
                        loader: 'css-loader',
                        options: {
                            importLoaders: 1
                        }
                    },
                    {
                        loader: 'postcss-loader',
                        options: {
                            plugins: loaders => [
                                require('autoprefixer')()
                            ]
                        }
                    },
                    'less-loader',
                ]
            })
        }, {
            test: /\.css$/,
            use: ExtractTextPlugin.extract({
                fallback: 'style-loader',
                use: [
                    {
                        loader: 'css-loader',
                        options: {
                            importLoaders: 1
                        }
                    },
                    {
                        loader: 'postcss-loader',
                        options: {
                            plugins: loaders => [
                                require('autoprefixer')()
                            ]
                        }
                    }
                ]
            })
        }, {
            test: /\.(png|jpg)$/,
            use: 'url-loader?limit=8192&name=./image/[name].[ext]',
        }, {
            test: /\.jsx?$/,
            exclude: /(node_modules|bower_components)/,
            use: {
                loader: 'babel-loader',
                options: {
                    presets: ['env', 'react'],
                    plugins: ['transform-runtime'],
                }
            },
        }, {
            test: /\.(ttf|eot|svg|woff(2)?)(\?[a-z0-9]+)?$/,
            use: 'url-loader?limit=10000&name=./font/[name].[ext]',
        }],
    },
};
